@@ -2,7 +2,6 @@ from lxml import etree
 import logging
 
 from django.conf import settings
-from django.core.files.uploadedfile import SimpleUploadedFile
 from django.db import models
 from django_extensions.db.models import AutoSlugField, TimeStampedModel
 import dateutil.parser
@@ -12,6 +11,7 @@ logger = logging.getLogger(__name__)
 
 settings.PODCAST_DIRECTORY = getattr(settings, 'PODCAST_DIRECTORY', 'podcasts')
 
+
 class PodcastChannel(TimeStampedModel):
     url = models.URLField(unique=True)
     title = models.CharField(max_length=255, blank=True)
@@ -50,7 +50,6 @@ class PodcastChannel(TimeStampedModel):
         else:
             logger.error('Failed to retrieve feed. Status %s' % req.reason)
 
-
     def parse_cover_url(self, tree):
         image_url = getattr(
             tree.find('image/url'), 'text', None) or ''
@@ -67,7 +66,6 @@ class PodcastChannel(TimeStampedModel):
 
         return image_url
 
-
     def update_items(self, channel, download=False):
         new_items = []
         for item in channel.findall('item'):
@@ -106,7 +104,7 @@ class PodcastItem(models.Model):
     channel = models.ForeignKey(PodcastChannel, related_name='podcast_items')
     url = models.URLField()
     title = models.CharField(max_length=255, blank=True)
-    slug = AutoSlugField(populate_from=('channel', 'title'))
+    slug = AutoSlugField(populate_from=('channel', 'title'), overwrite=True)
     description = models.TextField(blank=True)
     author = models.CharField(max_length=255, blank=True)
     link = models.URLField(blank=True)
@@ -132,11 +130,20 @@ class PodcastItem(models.Model):
 
     def download_file(self):
         logger.info('Downloading - %s' % self.title)
-        req = requests.get(self.url)
+        req = requests.get(self.url, stream=True)
         if req.ok:
-            file = SimpleUploadedFile(
-                self.url, req.content, req.headers['content-type'])
-            self.file.save(self.url, file)
+            # some downloads are tooo big to keep in memory
+            filename = req.request.path_url.split(
+                '/')[-1].split('?')[0].split('#')[0]
+            file_path = '%s/%s' % (settings.PODCAST_DIRECTORY, filename)
+            path = '%s/%s' % (settings.MEDIA_ROOT, file_path)
+            with open(path, 'wb') as f:
+                for block in req.iter_content(1024):
+                    if not block:
+                        break
+                    f.write(block)
+            self.file = file_path
+            self.save()
         else:
             logger.error('Failed to retrieve file. Status %s' % req.reason)
 
